 /*
    * Copyright (c) 2012, H. J. Ohlbach. All rights reserved.
    * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
    *
    * This code is free software; you can redistribute it and/or modify it
    * under the terms of the GNU General Public License version 2 only, as
    * published by the Free Software Foundation. 
    *
    * This code is distributed in the hope that it will be useful, but WITHOUT
    * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
    * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
    * version 2 for more details.
    */
package Java2OWL;

import java.lang.annotation.*;

/** This is an annotation for getter-methods which are mapped to OWL-properties.
 *
 * @author ohlbach
 */
@Documented
@Retention(value=RetentionPolicy.RUNTIME)
@Target({ElementType.METHOD})
public @interface J2OWLProperty {
    /** The name of the generated OWL-property. */
    String name() default "";
    
    /** If true then the name of the generated OWL-property is prefixed with the class name. */
    boolean local() default false;
    
    /** The name of the setter method. */
    String setter() default "";     
    
    /** The name of the adder method. */
    String adder() default "";  
    
    /** The name of the remover method. */
    String remover() default ""; 
    
    /** The name of the clearer method. */
    String clearer() default ""; 
    
    /** The name of the getKey method. */
    String getKey() default ""; 
    
    /** a relational property is made transitive. */
    boolean transitive() default false;
    
    /** a relational property is made symmetric. */
    boolean symmetric() default false;
    
    /** a relational property is made asymmetric. */
    boolean asymmetric() default false;
    
    /** a relational property is made reflexive. */
    boolean reflexive() default false;
    
    /** a relational property is made irreflexive. */
    boolean irreflexive() default false;
    
    /** a functional property is made total. */
    boolean total() default false;
    
    /** a range axiom is to be added to the generated OWL-property. */ 
    boolean addRangeAxiom() default true;

    /** minimum number of role-fillers. */
    int atleast() default -1;
    
    /** maximum number of role-fillers. */
    int atmost() default -1;
}
